"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPolkadotApi = void 0;
const api_1 = require("@polkadot/api");
const lru_cache_1 = __importDefault(require("lru-cache"));
const tenMin = 10 * 60 * 1000;
const cache = new lru_cache_1.default({
    max: 20,
    ttl: tenMin,
    updateAgeOnGet: true,
    ttlAutopurge: true,
    dispose: (api) => api.isConnected && api.disconnect(),
});
async function getPolkadotApi(ws) {
    const cached = cache.get(ws);
    if (cached) {
        return cached;
    }
    const newApi = await api_1.ApiPromise.create({
        provider: new api_1.WsProvider(ws),
    });
    await newApi.isReady;
    cache.set(ws, newApi);
    return newApi;
}
exports.getPolkadotApi = getPolkadotApi;
//# sourceMappingURL=polkadot.api.js.map